@@ -356,7 +356,8 @@ audio_view_media_get_metadata (GstMediaInfoStream *info)
 }
 
 /* set next track to play
- * return FALSE if this is the last track */
+ * return FALSE if this is the last track or if the next track is not
+ * playable */
 static gboolean
 audio_view_play_next (AudioView *view)
 {
@@ -366,6 +367,7 @@ audio_view_play_next (AudioView *view)
 	GtkTreeIter iter;
 	GtkTreePath *path;
 	GstMediaInfoStream *info;
+	gchar *message;
 
 	g_assert (IS_AUDIO_PLAY (play));
 	NM_DEBUG("play_next: start\n");
@@ -391,10 +393,24 @@ audio_view_play_next (AudioView *view)
 				    AUDIO_INFO_COLUMN, &info,
 				    -1);
 		NM_DEBUG("play_next: track to play is %s\n", info->path);
+
+	if (!audio_view_is_playable (info->path))
+        {
+		NM_DEBUG("play_next: %s is not playable\n", info->path);
+		return FALSE;
 	}
 	audio_view_set_playing (view, info, path);
-	gtk_tree_path_free (path);
-	return TRUE;
+		audio_view_set_playing (view, info, path);
+		gtk_tree_path_free (path);
+		return TRUE;
+	}
+	else
+	{
+		message = g_strdup_printf (_("Make a selection first !"));
+		gtk_label_set_text (GTK_LABEL (view->status), message);
+		g_free (message);
+		return FALSE;
+	}
 }
 
 /* timeout for scanner */
@@ -594,6 +610,7 @@ prev_activate (GtkButton *prev_button, AudioView *view)
 	GtkTreeIter iter;
 	GtkTreePath *path;
 	GstMediaInfoStream *info;
+	gchar *message;
 
 	play = view->audio_play;
 	g_assert (IS_AUDIO_PLAY (play));
@@ -611,8 +628,15 @@ prev_activate (GtkButton *prev_button, AudioView *view)
 		gtk_tree_model_get (model, &iter,
 				    AUDIO_INFO_COLUMN, &info,
 				    -1);
+	
+		audio_view_set_playing (view, info, path);
+	}
+	else
+	{
+		message = g_strdup_printf (_("Make a selection first !"));
+		gtk_label_set_text (GTK_LABEL (view->status), message);
+		g_free (message);
 	}
-	audio_view_set_playing (view, info, path);
 }
 
 static void
