@@ -19,6 +19,10 @@
 
 /* media-info-priv.c - handling of internal stuff */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <gst/gst.h>
 #include <string.h>
 #include "media-info.h"
@@ -102,9 +106,16 @@ deep_notify_callback (GObject *object, GstObject *origin,
       g_object_get_property (G_OBJECT (origin), pspec->name, &value);
       priv->format = g_value_peek_pointer (&value);
     }
-    else GMI_DEBUG("DEBUG: igoring caps on object %s:%s\n",
+    else
+    {
+      /* FIXME: somehow with 0.7.2 the signalisation comes from typefind:src */
+      GMI_DEBUG("DEBUG: taking caps from object %s:%s\n",
 		   gst_object_get_name (gst_object_get_parent (origin)),
 		   gst_object_get_name (origin));
+      g_value_init (&value, pspec->value_type);
+      g_object_get_property (G_OBJECT (origin), pspec->name, &value);
+      priv->format = g_value_peek_pointer (&value);
+    }
   }
   else if (strcmp (pspec->name, "offset") == 0)
   {
@@ -182,9 +193,8 @@ gmi_seek_to_track (GstMediaInfo *info, long track)
   res = gst_pad_send_event (info->priv->decoder_pad, event);
   if (!res)
   {
-    g_warning ("seek to logical track on pad %s:%s failed of element %s",
-               GST_DEBUG_PAD_NAME(info->priv->decoder_pad),
-               gst_element_get_factory((gst_pad_get_parent(info->priv->decoder_pad)))->details->longname);
+    g_warning ("seek to logical track on pad %s:%s failed",
+               GST_DEBUG_PAD_NAME(info->priv->decoder_pad));
     return FALSE;
   }
   /* clear structs because of the seek */
@@ -262,7 +272,7 @@ gmi_set_decoder (GstMediaInfo *info, GstElement *decoder)
   /* set up pipeline and connect signal handlers */
   priv->decoder = decoder;
   gst_bin_add (GST_BIN (priv->pipeline), decoder);
-  if (!gst_element_connect (priv->source, decoder))
+  if (!gst_element_link (priv->source, decoder))
     g_warning ("Couldn't connect source and decoder\n");
   /* FIXME: we should be connecting to ALL possible src pads */
   if (!(priv->decoder_pad = gst_element_get_pad (decoder, "src")))
@@ -281,7 +291,7 @@ gmi_clear_decoder (GstMediaInfo *info)
     /* clear up decoder */
 	  /* FIXME: shouldn't need to set state here */
     gst_element_set_state (info->priv->pipeline, GST_STATE_READY);
-    gst_element_disconnect (info->priv->source, info->priv->decoder);
+    gst_element_unlink (info->priv->source, info->priv->decoder);
     gst_bin_remove (GST_BIN (info->priv->pipeline), info->priv->decoder);
     info->priv->decoder = NULL;
   }
@@ -313,7 +323,7 @@ gmip_find_type_pre (GstMediaInfoPriv *priv)
 
   gst_bin_add (GST_BIN (priv->pipeline), priv->typefind);
   g_object_set (G_OBJECT (priv->source), "location", priv->location, NULL);
-  if (!gst_element_connect (priv->source, priv->typefind))
+  if (!gst_element_link (priv->source, priv->typefind))
     g_warning ("Couldn't connect source and typefind\n");
   g_signal_connect (G_OBJECT (priv->typefind), "have-type",
 		    G_CALLBACK (have_type_callback), priv);
@@ -333,7 +343,7 @@ gmip_find_type_post (GstMediaInfoPriv *priv)
 {
   /*clear up typefind */
   gst_element_set_state (priv->pipeline, GST_STATE_READY);
-  gst_element_disconnect (priv->source, priv->typefind);
+  gst_element_unlink (priv->source, priv->typefind);
   gst_bin_remove (GST_BIN (priv->pipeline), priv->typefind);
 
   if (priv->type == NULL)
@@ -414,7 +424,7 @@ gmip_find_stream_post (GstMediaInfoPriv *priv)
           stream->length_time = value;
           GMI_DEBUG("  total %s: %lld\n", definition->nick, value);
 	  break;
-	case GST_FORMAT_UNITS:
+	case GST_FORMAT_DEFAULT:
 	case GST_FORMAT_BYTES:
 	  break;
 	default:
@@ -442,7 +452,7 @@ gmip_find_stream_post (GstMediaInfoPriv *priv)
                        &format, &value);
   if (!res) g_warning ("Failed to query on sink pad !");
   bytes = value;
-  GMI_DEBUG("bitrate calc: bytes gotten: %d\n", bytes);
+  GMI_DEBUG("bitrate calc: bytes gotten: %ld\n", bytes);
 
   if (bytes)
   {
@@ -517,6 +527,8 @@ gmip_find_track_metadata (GstMediaInfoPriv *priv)
     GMI_DEBUG("+");
   GMI_DEBUG("\n");
   gmip_find_track_metadata_post (priv);
+
+  return TRUE;
 }
 
 /* find streaminfo found by decoder and store in priv->streaminfo */
@@ -581,6 +593,8 @@ gmip_find_track_streaminfo_post (GstMediaInfoPriv *priv)
   }
   priv->current_track->streaminfo = priv->streaminfo;
   priv->streaminfo = NULL;
+
+  return TRUE;
 }
 
 gboolean
@@ -593,6 +607,8 @@ gmip_find_track_streaminfo (GstMediaInfoPriv *priv)
     GMI_DEBUG("+");
   GMI_DEBUG("\n");
   gmip_find_track_streaminfo_post (priv);
+
+  return TRUE;
 }
 
 /* find format found by decoder and store in priv->format */
@@ -629,6 +645,8 @@ gmip_find_track_format (GstMediaInfoPriv *priv)
     GMI_DEBUG("+");
   GMI_DEBUG("\n");
   gmip_find_track_format_post (priv);
+
+  return TRUE;
 }
 
 
