@@ -29,13 +29,18 @@ typedef struct GstMediaInfoPriv		GstMediaInfoPriv;
 typedef struct _GstMediaInfo            GstMediaInfo;
 typedef struct _GstMediaInfoClass       GstMediaInfoClass;
 
+/* FIXME: temporary workaround until gst 0.7.3 is released */
+#ifndef GST_PADDING
+#define GST_PADDING 4
+#endif
+
 struct _GstMediaInfo
 {
   GObject parent;
 
   GstMediaInfoPriv *priv;
 
-  GST_OBJECT_PADDING
+  gpointer _gst_reserved[GST_PADDING];
 };
 
 struct _GstMediaInfoClass
@@ -43,9 +48,9 @@ struct _GstMediaInfoClass
   GObjectClass parent_class;
 
   /* signals */
-  void (*media_info_signal) 		(GstMediaInfo *gst_media_info);
+  void (*media_info_signal)		(GstMediaInfo *gst_media_info);
 
-  GST_CLASS_PADDING
+  gpointer _gst_reserved[GST_PADDING];
 };
 
 /* structure for "physical" stream,
